@@ -76,7 +76,12 @@ def event_filter(events):
   Takes a list of events, returns a filtered list of events (generator).
   The events to include are the teaching events.
   """
-  events_whitelist = ["Datorlaboration", "Laboration", "Föreläsning", "Övning"]
+  events_whitelist = [
+    "Datorlaboration", "Laboration",
+    "Övning",
+    "Seminarium", "Redovisning", "Examination",
+    "Föreläsning"
+  ]
 
   for event in events:
     for event_type in events_whitelist:
@@ -249,6 +254,7 @@ def hours_per_TA(csv_rows):
     booked, _ = get_booked_TAs_from_csv(row)
 
     for assistant in booked:
+      assistant = assistant.casefold()
       if assistant in TA_hours:
         TA_hours[assistant] += time
       else:
